<?xml version="1.0"?>
<!--

  This stylesheet converts an XML file, as output by peng, into a nice
  HTML page.

  Usage:
    peng -Xs >somefile.xml
    xsltproc summary.xsl somefile.xml >somefile.html
  You can pass parameters:
    xsltproc ++param NAME "'PList" ++param STYLE "'http://my.server/plist.css'" summary.xsl plist.xml > plist.html
  (note that ++ actually is double-hyphen but XML does not let me
  write that in a comment)

  A nice stylesheet for the generated HTML page is distributed with
  peng in summary.css.

  This assumes at some places that the XML file has elements in
  correct order (e.g. fuel usage).

-->
<xsl:stylesheet version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

 <xsl:param name="NAME">My Ship List</xsl:param>
 <xsl:param name="STYLE">summary.css</xsl:param>

 <xsl:template match="shiplist">
  <html>
   <head>
    <title><xsl:value-of select="$NAME" /></title>
    <style src="{$STYLE}" type="text/css" title="Normal Stylesheet">
    </style>
   </head>

   <h1><xsl:value-of select="$NAME" /></h1>

   <h2>Ship Types</h2>

   <table>
    <tr>
     <th rowspan="2">Name</th>
     <th colspan="3">Arms</th>
     <th colspan="4">Cost</th>
     <th rowspan="2">Tech</th>
     <th rowspan="2">Mass</th>
     <th rowspan="2">Cargo</th>
     <th rowspan="2">Fuel</th>
     <th rowspan="2">Engines</th>
     <th rowspan="2">Crew</th>
     <th rowspan="2">Players</th>
    </tr>
    <tr>
     <th>Beams</th>
     <th>Tubes</th>
     <th>Bays</th>
     <th>mc</th>
     <th>Tri</th>
     <th>Dur</th>
     <th>Mol</th>
    </tr>
    <xsl:apply-templates select="hulls/hull" />
   </table>

   <h2>Engine Types</h2>

   <table>
    <tr>
     <th rowspan="2">Name</th>
     <th colspan="4">Cost</th>
     <th rowspan="2">Tech</th>
     <th colspan="9">Fuel Usage</th>
    </tr>
    <tr>
     <th>mc</th>
     <th>Tri</th>
     <th>Dur</th>
     <th>Mol</th>
     <th>w1</th>
     <th>w2</th>
     <th>w3</th>
     <th>w4</th>
     <th>w5</th>
     <th>w6</th>
     <th>w7</th>
     <th>w8</th>
     <th>w9</th>
    </tr>
    <xsl:apply-templates select="engines/engine" />
   </table>

   <h2>Beam Weapon Types</h2>

   <table>
    <tr>
     <th rowspan="2">Name</th>
     <th colspan="4">Cost</th>
     <th rowspan="2">Tech</th>
     <th colspan="2">Impact</th>
    </tr>
    <tr>
     <th>mc</th>
     <th>Tri</th>
     <th>Dur</th>
     <th>Mol</th>
     <th>Kill</th>
     <th>Destroy</th>
    </tr>
    <xsl:apply-templates select="beams/beam" />
   </table>
   
   <h2>Torpedo Types</h2>

   <table>
    <tr>
     <th rowspan="2">Name</th>
     <th colspan="4">Cost</th>
     <th rowspan="2">Torp Cost<br />(mc)</th>
     <th rowspan="2">Tech</th>
     <th colspan="2">Impact</th>
    </tr>
    <tr>
     <th>mc</th>
     <th>Tri</th>
     <th>Dur</th>
     <th>Mol</th>
     <th>Kill</th>
     <th>Destroy</th>
    </tr>
    <xsl:apply-templates select="torps/torp" />
   </table>

   <h2>Players' Ships</h2>

   <dl class="p">
    <xsl:for-each select="//truehull/race">
     <dt><a name="p{@n}">Player <xsl:value-of select="@n" /></a></dt>
     <dd>
      <ul>
       <xsl:for-each select="racehull">
        <xsl:if test="@n != '0'">
         <xsl:variable name="thishull" select="@n" />
         <li><a href="#h{@n}"><xsl:value-of select="//hulls/hull[@n = $thishull]/name/text()" /></a></li>
        </xsl:if>
       </xsl:for-each>
      </ul>
     </dd>
    </xsl:for-each>
   </dl>
  </html>
 </xsl:template>

 <xsl:template match="hull">
  <tr>
   <td class="t"><a name="h{@n}"><xsl:apply-templates select="name" /></a></td>
   <td><xsl:apply-templates select="nbeams" /></td>
   <td><xsl:apply-templates select="ntubes" /></td>
   <td><xsl:apply-templates select="nbays" /></td>
   <td><xsl:apply-templates select="cost" /></td>
   <td><xsl:apply-templates select="tri" /></td>
   <td><xsl:apply-templates select="dur" /></td>
   <td><xsl:apply-templates select="mol" /></td>
   <td><xsl:apply-templates select="tech" /></td>
   <td><xsl:apply-templates select="mass" /></td>
   <td><xsl:apply-templates select="cargo" /></td>
   <td><xsl:apply-templates select="fuel" /></td>
   <td><xsl:apply-templates select="nengines" /></td>
   <td><xsl:apply-templates select="crew" /></td>
   <td class="t">
    <xsl:variable name="thishull" select="@n" />
    <xsl:for-each select="//truehull/race/racehull[@n = $thishull]">
     <xsl:variable name="thisply"><xsl:value-of select="../@n" /></xsl:variable>
     <a href="#p{$thisply}"><xsl:value-of select="$thisply" /></a><xsl:text xml:space="preserve"> </xsl:text>
    </xsl:for-each>
   </td>
  </tr>
 </xsl:template>

 <xsl:template match="engine">
  <tr>
   <td class="t"><a name="e{@n}"><xsl:apply-templates select="name" /></a></td>
   <td><xsl:apply-templates select="cost" /></td>
   <td><xsl:apply-templates select="tri" /></td>
   <td><xsl:apply-templates select="dur" /></td>
   <td><xsl:apply-templates select="mol" /></td>
   <td><xsl:apply-templates select="tech" /></td>
   <xsl:for-each select="fuelusage/warp">
    <td>
     <xsl:value-of select="round(@v div (@n*@n))" />
     </td>
   </xsl:for-each>
  </tr>
 </xsl:template>

 <xsl:template match="beam">
  <tr>
   <td class="t"><a name="b{@n}"><xsl:apply-templates select="name" /></a></td>
   <td><xsl:apply-templates select="cost" /></td>
   <td><xsl:apply-templates select="tri" /></td>
   <td><xsl:apply-templates select="dur" /></td>
   <td><xsl:apply-templates select="mol" /></td>
   <td><xsl:apply-templates select="tech" /></td>
   <td><xsl:apply-templates select="kill" /></td>
   <td><xsl:apply-templates select="damage" /></td>
  </tr>
 </xsl:template>

 <xsl:template match="torp">
  <tr>
   <td class="t"><a name="t{@n}"><xsl:apply-templates select="name" /></a></td>
   <td><xsl:apply-templates select="cost" /></td>
   <td><xsl:apply-templates select="tri" /></td>
   <td><xsl:apply-templates select="dur" /></td>
   <td><xsl:apply-templates select="mol" /></td>
   <td><xsl:apply-templates select="torpcost" /></td>
   <td><xsl:apply-templates select="tech" /></td>
   <td><xsl:apply-templates select="kill" /></td>
   <td><xsl:apply-templates select="damage" /></td>
  </tr>
 </xsl:template>
</xsl:stylesheet>